Name: klibc
Version: 1.5.18
Release: alt1

Summary: A minimal libc subset for use with initramfs
License: BSD/GPL
Group: System/Libraries
URL: http://www.zytor.com/mailman/listinfo/klibc

# git://git.kernel.org/pub/scm/libs/klibc/klibc
Source: %name-%version.tar
Patch: %name-%version-%release.patch

# due to %%base_arch
BuildPreReq: rpm-build-kernel

%define klibcdir  %_libdir/klibc
%define libdocdir %_docdir/%name-%version-%release
%define bindocdir %_docdir/%name-utils-%version-%release

# Use special scripts to find dependencies on klibc-*.so (default RPM scripts
# do not pick up these dependencies).
%global __find_provides %_builddir/%name-%version/klibc-find-provides %__find_provides
%global __find_requires %_builddir/%name-%version/klibc-find-requires %__find_requires

%description
%name is intended to be a minimalistic libc subset for use with
initramfs.  It is deliberately written for small size, minimal
entanglement, and portability, not speed.

%package devel
Summary: Libraries and tools needed to compile applications against klibc
Group: Development/C
Requires: %name = %version-%release

%description devel
This package contains the link libraries, header files, and gcc
wrapper scripts needed to compile applications against klibc.

%package utils
Summary: Small utilities built with klibc
Group: System/Kernel and hardware
Requires: %name = %version-%release

%description utils
This package contains a collection of programs that are linked against
klibc.  These duplicate some of the functionality of a regular Linux
toolset, but are typically much smaller than their full-function
counterparts.  They are intended for inclusion in initramfs images and
embedded systems.

%package utils-initramfs
Summary: Utilities for initramfs images generated by mkinitrd
Group: System/Kernel and hardware
Requires: %name = %version-%release
PreReq: mkinitrd-initramfs

%description utils-initramfs
This package contains utilities for use in initramfs images
generated by mkinitrd.

%prep
%setup
%patch -p1
chmod a+x klibc-find-provides klibc-find-requires

# Assume that adjust_kernel_headers --first has been run.
mkdir -p linux/include
ln -s "$(readlink -ev /usr/include/linux/../..)"/include/* linux/include/

%ifarch %arm
# Enable EABI support in config
echo 'CONFIG_AEABI=y' >> defconfig
%endif

%build
%make_build \
	KLIBCARCH=%base_arch prefix=%prefix bindir=%_bindir \
	SHLIBDIR=/%_lib \
	INSTALLDIR=%klibcdir mandir=%_mandir INSTALLROOT=%buildroot

%install
%make_install KLIBCARCH=%base_arch prefix=%prefix bindir=%_bindir \
	SHLIBDIR=/%_lib \
	INSTALLDIR=%klibcdir mandir=%_mandir INSTALLROOT=%buildroot \
	install

# Install fixed scsi headers
cp -a %_includedir/scsi %buildroot%klibcdir/include/
sed -i 's|features.h|sys/stat.h|' %buildroot%klibcdir/include/scsi/*.h

install -p klibc-find-requires %buildroot%klibcdir/

# Install the docs
mkdir -p %buildroot%bindocdir %buildroot%libdocdir
install -pm644 README %buildroot%libdocdir
install -pm644 usr/klibc/README.klibc %buildroot%libdocdir/
install -pm644 usr/klibc/arch/README.klibc.arch %buildroot%libdocdir/

install -pm644 usr/gzip/COPYING %buildroot%bindocdir/COPYING.gzip
install -pm644 usr/gzip/README %buildroot%bindocdir/README.gzip
install -pm644 usr/kinit/ipconfig/README.ipconfig %buildroot%bindocdir/
install -pm644 usr/kinit/README %buildroot%bindocdir/README.kinit

# This file must have normal symbols - they are used for linking
# (klibc does not use the dynamic symbol table).
%add_strip_skiplist %klibcdir/lib/libc.so

# Install mkinitrd-klibc files
klibc_soname=`cd %buildroot/%_lib && ls -1 klibc-*.so`
mkdir -p %buildroot/lib/mkinitrd/klibc/{bin,sbin,%_lib}
ln -s /%_lib/"$klibc_soname" \
	%buildroot/lib/mkinitrd/klibc/%_lib/"$klibc_soname"
install -p usr/dash/sh.shared %buildroot/lib/mkinitrd/klibc/bin/sh
install -p usr/utils/shared/{cat,false,kill,ln,mkdir,mknod,mount,nuke,readlink,sleep,true,umount} \
	%buildroot/lib/mkinitrd/klibc/bin/
install -p usr/utils/shared/halt \
	%buildroot/lib/mkinitrd/klibc/sbin/
ln %buildroot/lib/mkinitrd/klibc/sbin/halt \
	%buildroot/lib/mkinitrd/klibc/sbin/poweroff
ln %buildroot/lib/mkinitrd/klibc/sbin/halt \
	%buildroot/lib/mkinitrd/klibc/sbin/reboot
for prog in fstype ipconfig md_run nfsmount resume run-init; do
	install -p usr/kinit/$prog/shared/$prog \
		%buildroot/lib/mkinitrd/klibc/bin/
done

find %buildroot%klibcdir/include -name \.\* -delete

%files
/%_lib/klibc-*.so

%files devel
%dir %klibcdir
%klibcdir/include
%klibcdir/lib
%klibcdir/klibc-find-requires
%_bindir/klcc
%_man1dir/*
%doc %libdocdir

%files utils
%dir %klibcdir
%klibcdir/bin
%doc %bindocdir

%files utils-initramfs
/lib/mkinitrd/klibc

%changelog
* Thu May 20 2010 Dmitry V. Levin <ldv@altlinux.org> 1.5.18-alt1
- Updated to 1.5.18.
- Fixed include/arch/i386/klibc/archsignal.h (closes: #23514).

* Fri Apr 02 2010 Dmitry V. Levin <ldv@altlinux.org> 1.5.17-alt2
- Build this package without optimizations based on strict aliasing rules.
- Fixed build with fresh glibc-kernheaders.
- Enhanced sys/socket.h to make it usable for building udev.

* Sat Mar 20 2010 Valery Inozemtsev <shrek@altlinux.ru> 1.5.17-alt1
- 1.5.17

* Sun Mar 14 2010 Valery Inozemtsev <shrek@altlinux.ru> 1.5.16-alt1
- 1.5.16

* Tue Nov 10 2009 Valery Inozemtsev <shrek@altlinux.ru> 1.5.15-alt4
- build with kernel-headers-std-def

* Tue Jul 21 2009 Valery Inozemtsev <shrek@altlinux.ru> 1.5.15-alt3
- implementing signalfd()
- fixed faccessat(), linkat(), fchmodat(), unlinkat()

* Fri Jul 17 2009 Valery Inozemtsev <shrek@altlinux.ru> 1.5.15-alt2
- rebuild

* Sun Jan 04 2009 Valery Inozemtsev <shrek@altlinux.ru> 1.5.15-alt1
- 1.5.15

* Thu Nov 27 2008 Valery Inozemtsev <shrek@altlinux.ru> 1.5.14-alt2
- rebuild

* Thu Sep 11 2008 Kirill A. Shutemov <kas@altlinux.ru> 1.5.14-alt1.2
- Enable EABI support on ARM

* Tue Sep 09 2008 Kirill A. Shutemov <kas@altlinux.ru> 1.5.14-alt1.1
- NMU:
  + build with glibc-kernheaders
  + replace kernel-build-tools with rpm-build-kernel to reduce build
    dependents

* Sat Aug 02 2008 Valery Inozemtsev <shrek@altlinux.ru> 1.5.14-alt1
- 1.5.14

* Tue Jul 08 2008 Valery Inozemtsev <shrek@altlinux.ru> 1.5.12-alt1
- 1.5.12

* Mon Jun 16 2008 Valery Inozemtsev <shrek@altlinux.ru> 1.5.11-alt1
- 1.5.11

* Wed Jun 11 2008 Valery Inozemtsev <shrek@altlinux.ru> 1.5.10-alt1
- 1.5.10

* Thu Mar 29 2007 Sergey Vlasov <vsu@altlinux.ru> 1.5-alt1
- Version 1.5.

* Mon Feb 19 2007 Sergey Vlasov <vsu@altlinux.ru> 1.4.34-alt1
- Version 1.4.34.
- Fixed broken shared library build on x86_64 with binutils versions having
  max-page-size=0x200000 (caused immediate segfault on kernels with the
  exec-shield patch applied).

* Thu Feb 08 2007 Sergey Vlasov <vsu@altlinux.ru> 1.4.32-alt1
- First build for ALT Linux.
- Version 1.4.32.
- Spec file cleanup according to ALT conventions.
- Use kernel-headers-std >= 2.6.18 headers for build.
- Move klibc-*.so from /lib to /%%_lib (which is /lib64 on x86_64).
- Move other klibc files to %%_libdir instead of %%_prefix/lib.
- Move libc.so and interp.o to the devel subpackage (RPM dependencies should
  prevent mismatches between runtime and devel packages).
- Do not strip libc.so (klibc uses normal symbols for linking).
- Add klibc-find-provides and klibc-find-requires scripts to generate proper
  dependencies on /%%_lib/klibc-*.so (klibc-find-provides is used privately,
  klibc-find-requires is available in the devel subpackage for use by other
  packages which link with klibc).
- Add klibc-utils-initramfs subpackage which contains the subset of
  utilities used by mkinitrd-generated initramfs images; these files are
  installed under /lib/mkinitrd to make them available even without /usr.
- Add md_run utility to handle old-style RAID startup separate from kinit.
- umount: Add -l option for lazy unmount.

* Tue Mar 1 2005 H. Peter Anvin <hpa@zytor.com>
- New "make install" scheme, klcc

* Tue Jul 6 2004 H. Peter Anvin <hpa@zytor.com>
- Update to use kernel-source RPM for the kernel symlink.

* Sat Nov 29 2003 Bryan O'Sullivan <bos@serpentine.com> -
- Initial build.
